@@ -4,7 +4,7 @@
 # See top-level LICENSE file for more information
 
 import json
-from typing import Any, Dict, cast
+from typing import Any, Dict, Union, cast
 
 from cryptography.fernet import InvalidToken
 
@@ -14,6 +14,7 @@ from django.core.paginator import Paginator
 from django.http import HttpRequest
 from django.http.response import (
     HttpResponse,
+    HttpResponseBadRequest,
     HttpResponseForbidden,
     HttpResponseRedirect,
     JsonResponse,
@@ -25,6 +26,7 @@ from swh.auth.django.models import OIDCUser
 from swh.auth.django.utils import keycloak_oidc_client
 from swh.auth.django.views import get_oidc_login_data, oidc_login_view
 from swh.auth.django.views import urlpatterns as auth_urlpatterns
+from swh.auth.keycloak import KeycloakError, keycloak_error_message
 from swh.web.auth.models import OIDCUserOfflineTokens
 from swh.web.auth.utils import decrypt_data, encrypt_data
 from swh.web.common.exc import ForbiddenExc
@@ -90,6 +92,14 @@ def oidc_list_bearer_tokens(request: HttpRequest) -> HttpResponse:
     return JsonResponse(table_data)
 
 
+def _encrypted_token_bytes(token: Union[bytes, memoryview]) -> bytes:
+    # token has been retrieved from a PosgreSQL database
+    if isinstance(token, memoryview):
+        return token.tobytes()
+    else:
+        return token
+
+
 @require_http_methods(["POST"])
 def oidc_get_bearer_token(request: HttpRequest) -> HttpResponse:
     if not request.user.is_authenticated or not isinstance(request.user, OIDCUser):
@@ -100,10 +110,24 @@ def oidc_get_bearer_token(request: HttpRequest) -> HttpResponse:
         token_data = OIDCUserOfflineTokens.objects.get(id=data["token_id"])
         secret = get_config()["secret_key"].encode()
         salt = user.sub.encode()
-        decrypted_token = decrypt_data(token_data.offline_token, secret, salt)
-        return HttpResponse(decrypted_token.decode("ascii"), content_type="text/plain")
+        decrypted_token = decrypt_data(
+            _encrypted_token_bytes(token_data.offline_token), secret, salt
+        )
+        refresh_token = decrypted_token.decode("ascii")
+        # check token is still valid
+        oidc_client = keycloak_oidc_client()
+        oidc_client.refresh_token(refresh_token)
+        return HttpResponse(refresh_token, content_type="text/plain")
     except InvalidToken:
         return HttpResponse(status=401)
+    except KeycloakError as ke:
+        error_msg = keycloak_error_message(ke)
+        if error_msg in (
+            "invalid_grant: Offline session not active",
+            "invalid_grant: Offline user session not found",
+        ):
+            error_msg = "Bearer token has expired, please generate a new one."
+        return HttpResponseBadRequest(error_msg, content_type="text/plain")
 
 
 @require_http_methods(["POST"])
@@ -117,7 +141,9 @@ def oidc_revoke_bearer_tokens(request: HttpRequest) -> HttpResponse:
             token_data = OIDCUserOfflineTokens.objects.get(id=token_id)
             secret = get_config()["secret_key"].encode()
             salt = user.sub.encode()
-            decrypted_token = decrypt_data(token_data.offline_token, secret, salt)
+            decrypted_token = decrypt_data(
+                _encrypted_token_bytes(token_data.offline_token), secret, salt
+            )
             oidc_client = keycloak_oidc_client()
             oidc_client.logout(decrypted_token.decode("ascii"))
             token_data.delete()
