@@ -9,14 +9,13 @@ from django.shortcuts import redirect
 from swh.web.browse.browseurls import browse_route
 from swh.web.browse.snapshot_context import (
     browse_snapshot_branches,
-    browse_snapshot_content,
     browse_snapshot_directory,
     browse_snapshot_log,
     browse_snapshot_releases,
     get_snapshot_context,
 )
 from swh.web.common.exc import BadInputExc
-from swh.web.common.utils import reverse
+from swh.web.common.utils import redirect_to_new_route, reverse
 
 
 def get_snapshot_from_request(request):
@@ -93,17 +92,16 @@ def snapshot_directory_browse_legacy(request, snapshot_id, path=None):
     checksum_args=["snapshot_id"],
 )
 def snapshot_content_browse(request, snapshot_id):
-    """Django view that produces an HTML display of a content
+    """
+    This route is deprecated; use http:get:`/browse/content` instead
+
+    Django view that produces an HTML display of a content
     collected in a snapshot.
 
     The url that points to it is :http:get:`/browse/snapshot/(snapshot_id)/content/`
     """
-    return browse_snapshot_content(
-        request,
-        snapshot_id=snapshot_id,
-        path=request.GET.get("path"),
-        selected_language=request.GET.get("language"),
-    )
+
+    return redirect_to_new_route(request, "browse-content")
 
 
 @browse_route(
@@ -112,18 +110,16 @@ def snapshot_content_browse(request, snapshot_id):
     checksum_args=["snapshot_id"],
 )
 def snapshot_content_browse_legacy(request, snapshot_id, path):
-    """Django view that produces an HTML display of a content
+    """
+    This route is deprecated; use http:get:`/browse/content` instead
+
+    Django view that produces an HTML display of a content
     collected in a snapshot.
 
     The url that points to it is
     :http:get:`/browse/snapshot/(snapshot_id)/content/(path)/`
     """
-    return browse_snapshot_content(
-        request,
-        snapshot_id=snapshot_id,
-        path=path,
-        selected_language=request.GET.get("language"),
-    )
+    return redirect_to_new_route(request, "browse-content")
 
 
 @browse_route(
@@ -161,29 +157,69 @@ def snapshot_log_browse(request, snapshot_id=None):
 
 @browse_route(
     r"snapshot/(?P<snapshot_id>[0-9a-f]+)/branches/",
+    r"snapshot/branches/",
     view_name="browse-snapshot-branches",
     checksum_args=["snapshot_id"],
 )
-def snapshot_branches_browse(request, snapshot_id):
-    """Django view that produces an HTML display of the list of releases
+def snapshot_branches_browse(request, snapshot_id=None):
+    """Django view that produces an HTML display of the list of branches
     collected in a snapshot.
 
-    The url that points to it is
-    :http:get:`/browse/snapshot/(snapshot_id)/branches/`
+    The URLs that point to it are
+    :http:get:`/browse/snapshot/(snapshot_id)/branches/` and
+    :http:get:`/browse/snapshot/branches/`
     """
-    return browse_snapshot_branches(request, snapshot_id=snapshot_id)
+    if snapshot_id is None:
+        # This case happens when redirected from /origin/branches
+        snapshot_id = get_snapshot_from_request(request)
+        # Redirect to the same route with the newest snapshot_id
+        # for the given origin
+        return redirect(
+            reverse(
+                "browse-snapshot-branches",
+                url_args={"snapshot_id": snapshot_id},
+                query_params=request.GET,
+            ),
+        )
+    return browse_snapshot_branches(
+        request,
+        snapshot_id=snapshot_id,
+        origin_url=request.GET.get("origin_url"),
+        timestamp=request.GET.get("timestamp"),
+        branch_name_include=request.GET.get("name_include"),
+    )
 
 
 @browse_route(
     r"snapshot/(?P<snapshot_id>[0-9a-f]+)/releases/",
+    r"snapshot/releases/",
     view_name="browse-snapshot-releases",
     checksum_args=["snapshot_id"],
 )
-def snapshot_releases_browse(request, snapshot_id):
+def snapshot_releases_browse(request, snapshot_id=None):
     """Django view that produces an HTML display of the list of releases
     collected in a snapshot.
 
-    The url that points to it is
+    The URLs that point to it are
     :http:get:`/browse/snapshot/(snapshot_id)/releases/`
+    :http:get:`/browse/snapshot/releases/`
     """
-    return browse_snapshot_releases(request, snapshot_id=snapshot_id)
+    if snapshot_id is None:
+        # This case happens when redirected from /origin/releases
+        snapshot_id = get_snapshot_from_request(request)
+        # Redirect to the same route with the newest snapshot_id
+        # for the given origin
+        return redirect(
+            reverse(
+                "browse-snapshot-releases",
+                url_args={"snapshot_id": snapshot_id},
+                query_params=request.GET,
+            ),
+        )
+    return browse_snapshot_releases(
+        request,
+        snapshot_id=snapshot_id,
+        origin_url=request.GET.get("origin_url"),
+        timestamp=request.GET.get("timestamp"),
+        release_name_include=request.GET.get("name_include"),
+    )
